summaryrefslogtreecommitdiff
path: root/src/mem/ruby/system/System.cc
diff options
context:
space:
mode:
authorDaniel Sanchez <sanchezd@stanford.edu>2009-05-11 10:38:44 -0700
committerDaniel Sanchez <sanchezd@stanford.edu>2009-05-11 10:38:44 -0700
commitab5e4a22b3893fb0ccdfbf466d46983caeb5948e (patch)
tree58681979392d2f395da7c284c2f42113939396ee /src/mem/ruby/system/System.cc
parent84a18e7fdc6106a04188254f940a0e987efe750c (diff)
downloadgem5-ab5e4a22b3893fb0ccdfbf466d46983caeb5948e.tar.xz
ruby: Removed System name clash by renaming ruby's System to RubySystem
Diffstat (limited to 'src/mem/ruby/system/System.cc')
-rw-r--r--src/mem/ruby/system/System.cc22
1 files changed, 11 insertions, 11 deletions
diff --git a/src/mem/ruby/system/System.cc b/src/mem/ruby/system/System.cc
index 6352d8a58..74d4ef90f 100644
--- a/src/mem/ruby/system/System.cc
+++ b/src/mem/ruby/system/System.cc
@@ -28,9 +28,9 @@
*/
/*
- * System.C
+ * RubySystem.C
*
* Description: See System.h
*
* $Id$
*
@@ -52,7 +52,7 @@
//#include "XactVisualizer.hh"
#include "M5Driver.hh"
-System::System()
+RubySystem::RubySystem()
{
DEBUG_MSG(SYSTEM_COMP, MedPrio,"initializing");
@@ -129,7 +129,7 @@ System::System()
}
-System::~System()
+RubySystem::~RubySystem()
{
for (int i = 0; i < m_chip_vector.size(); i++) {
delete m_chip_vector[i];
@@ -142,19 +142,19 @@ System::~System()
*/
}
-void System::printConfig(ostream& out) const
+void RubySystem::printConfig(ostream& out) const
{
- out << "\n================ Begin System Configuration Print ================\n\n";
+ out << "\n================ Begin RubySystem Configuration Print ================\n\n";
RubyConfig::printConfiguration(out);
out << endl;
getChip(0)->printConfig(out);
m_network_ptr->printConfig(out);
m_driver_ptr->printConfig(out);
m_profiler_ptr->printConfig(out);
- out << "\n================ End System Configuration Print ================\n\n";
+ out << "\n================ End RubySystem Configuration Print ================\n\n";
}
-void System::printStats(ostream& out)
+void RubySystem::printStats(ostream& out)
{
const time_t T = time(NULL);
tm *localTime = localtime(&T);
@@ -174,7 +174,7 @@ void System::printStats(ostream& out)
Chip::printStats(out);
}
-void System::clearStats() const
+void RubySystem::clearStats() const
{
m_profiler_ptr->clearStats();
m_network_ptr->clearStats();
@@ -187,7 +187,7 @@ void System::clearStats() const
}
}
-void System::recordCacheContents(CacheRecorder& tr) const
+void RubySystem::recordCacheContents(CacheRecorder& tr) const
{
for (int i = 0; i < m_chip_vector.size(); i++) {
for (int m_version = 0; m_version < RubyConfig::numberOfProcsPerChip(); m_version++) {
@@ -220,7 +220,7 @@ void System::opalLoadNotify()
// in setState. The SLICC spec must also define methods "isBlockShared"
// and "isBlockExclusive" that are specific to that protocol
//
-void System::checkGlobalCoherenceInvariant(const Address& addr ) {
+void RubySystem::checkGlobalCoherenceInvariant(const Address& addr ) {
NodeID exclusive = -1;
bool sharedDetected = false;
@@ -28,9 +28,9 @@
*
- * Description: See System.h
+ * Description: See RubySystem.h
*
* $Id$